==> qmmp_0.4.3.orig.tar.gz: qmmp-0.4.3/src/plugins/Input/vorbis/translations/vorbis_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="50"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg-Vorbis-Modul</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg-Vorbis-Dateien</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="124"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Über Ogg-Vorbis-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="125"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Qmmp Ogg-Vorbis-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="126"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="127"/>
        <source>Source code based on mq3 progect</source>
        <translation>Quellcode basiert auf dem mq3-Projekt</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>Abtastrate</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/Input/vorbis/translations/vorbis_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="50"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>Ogg-Vorbis-Modul</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Files</source>
        <translation>Ogg-Vorbis-Dateien</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="124"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>Über Ogg-Vorbis-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="125"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>Qmmp Ogg-Vorbis-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="126"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="127"/>
        <source>Source code based on mq3 progect</source>
        <translation>Quellcode basiert auf dem mq3-Projekt</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>Länge</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>Abtastrate</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
